==> zio-aws-fms_2.13-5.17.271.1-sources.jar: zio/aws/fms/model/PutAppsListResponse.scala <==
package zio.aws.fms.model
import zio.ZIO
import zio.aws.fms.model.primitives.ResourceArn
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class PutAppsListResponse(
    appsList: Optional[zio.aws.fms.model.AppsListData] = Optional.Absent,
    appsListArn: Optional[ResourceArn] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.fms.model.PutAppsListResponse = {
    import PutAppsListResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.fms.model.PutAppsListResponse
      .builder()
      .optionallyWith(appsList.map(value => value.buildAwsValue()))(_.appsList)
      .optionallyWith(
        appsListArn.map(value => ResourceArn.unwrap(value): java.lang.String)
      )(_.appsListArn)
      .build()
  }
  def asReadOnly: zio.aws.fms.model.PutAppsListResponse.ReadOnly =
    zio.aws.fms.model.PutAppsListResponse.wrap(buildAwsValue())
}
object PutAppsListResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.fms.model.PutAppsListResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.fms.model.PutAppsListResponse =
      zio.aws.fms.model.PutAppsListResponse(
        appsList.map(value => value.asEditable),
        appsListArn.map(value => value)
      )
    def appsList: Optional[zio.aws.fms.model.AppsListData.ReadOnly]
    def appsListArn: Optional[ResourceArn]
    def getAppsList
        : ZIO[Any, AwsError, zio.aws.fms.model.AppsListData.ReadOnly] =
      AwsError.unwrapOptionField("appsList", appsList)
    def getAppsListArn: ZIO[Any, AwsError, ResourceArn] =
      AwsError.unwrapOptionField("appsListArn", appsListArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.fms.model.PutAppsListResponse
  ) extends zio.aws.fms.model.PutAppsListResponse.ReadOnly {
    override val appsList: Optional[zio.aws.fms.model.AppsListData.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.appsList())
        .map(value => zio.aws.fms.model.AppsListData.wrap(value))
    override val appsListArn: Optional[ResourceArn] = zio.aws.core.internal
      .optionalFromNullable(impl.appsListArn())
      .map(value => zio.aws.fms.model.primitives.ResourceArn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.fms.model.PutAppsListResponse
  ): zio.aws.fms.model.PutAppsListResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-fms_3-5.17.157.2-sources.jar: zio/aws/fms/model/PutAppsListResponse.scala <==
package zio.aws.fms.model
import zio.ZIO
import zio.aws.fms.model.primitives.ResourceArn
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class PutAppsListResponse(
    appsList: Option[zio.aws.fms.model.AppsListData] = None,
    appsListArn: Option[ResourceArn] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.fms.model.PutAppsListResponse = {
    import PutAppsListResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.fms.model.PutAppsListResponse
      .builder()
      .optionallyWith(appsList.map(value => value.buildAwsValue()))(_.appsList)
      .optionallyWith(
        appsListArn.map(value => ResourceArn.unwrap(value): java.lang.String)
      )(_.appsListArn)
      .build()
  }
  def asReadOnly: zio.aws.fms.model.PutAppsListResponse.ReadOnly =
    zio.aws.fms.model.PutAppsListResponse.wrap(buildAwsValue())
}
object PutAppsListResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.fms.model.PutAppsListResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.fms.model.PutAppsListResponse =
      zio.aws.fms.model.PutAppsListResponse(
        appsList.map(value => value.asEditable),
        appsListArn.map(value => value)
      )
    def appsList: Option[zio.aws.fms.model.AppsListData.ReadOnly]
    def appsListArn: Option[ResourceArn]
    def getAppsList
        : ZIO[Any, AwsError, zio.aws.fms.model.AppsListData.ReadOnly] =
      AwsError.unwrapOptionField("appsList", appsList)
    def getAppsListArn: ZIO[Any, AwsError, ResourceArn] =
      AwsError.unwrapOptionField("appsListArn", appsListArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.fms.model.PutAppsListResponse
  ) extends zio.aws.fms.model.PutAppsListResponse.ReadOnly {
    override val appsList: Option[zio.aws.fms.model.AppsListData.ReadOnly] =
      scala
        .Option(impl.appsList())
        .map(value => zio.aws.fms.model.AppsListData.wrap(value))
    override val appsListArn: Option[ResourceArn] = scala
      .Option(impl.appsListArn())
      .map(value => zio.aws.fms.model.primitives.ResourceArn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.fms.model.PutAppsListResponse
  ): zio.aws.fms.model.PutAppsListResponse.ReadOnly = new Wrapper(impl)
}
